pub struct BlockItem {
pub block: BlockRef,
}Expand description
Behavior for items that place blocks.
Fields
block: BlockRefThe block this item places.
Implementations
Sourceimpl BlockItem
impl BlockItem
const PLACE_BLOCK_FLAGS: UpdateFlags = UpdateFlags::UPDATE_ALL_IMMEDIATE
Sourcepub const fn new(block: BlockRef) -> Self
pub const fn new(block: BlockRef) -> Self
Creates a new block item behavior for the given block.
fn place_with( &self, context: BlockPlaceContext<'_>, place_block: impl FnOnce(&BlockPlaceContext<'_>, BlockStateId) -> bool, ) -> InteractionResult
Sourcepub fn place(&self, context: BlockPlaceContext<'_>) -> InteractionResult
pub fn place(&self, context: BlockPlaceContext<'_>) -> InteractionResult
Places this block using an already constructed placement context.
fn place_block(context: &BlockPlaceContext<'_>, state: BlockStateId) -> bool